@@ -37,6 +37,8 @@ from .base import (
     PoscBase,
     PoscBaseException,
     PoscParentBase,
+    POSC_GLOBALS,
+    PoscGlobals,
     Projection,
     RequiredParameterNotProvided,
     Render,
@@ -172,6 +174,8 @@ __all__ = [
     "Polyhedron",
     "PoscBase",
     "PoscBaseException",
+    "PoscGlobals",
+    "POSC_GLOBALS",
     "PoscModifiers",
     "PoscParentBase",
     "PoscRendererBase",
